==> foundation-v2-peercoin-0.0.2.tgz: package/README.md <==
# Foundation Stratum (Peercoin, v2)

[![Codecov Coverage](https://img.shields.io/codecov/c/github/blinkhash/foundation-v2-peercoin.svg?style=flat-square)](https://codecov.io/gh/blinkhash/foundation-v2-peercoin/)
[![Foundation CI](https://github.com/blinkhash/foundation-v2-peercoin/actions/workflows/build.yml/badge.svg?branch=master)](https://github.com/blinkhash/foundation-v2-peercoin/actions/workflows/build.yml)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Downloads](https://img.shields.io/npm/dm/foundation-v2-peercoin.svg)](https://www.npmjs.com/package/foundation-v2-peercoin)
[![Version](https://img.shields.io/npm/v/foundation-v2-peercoin.svg)](https://www.npmjs.com/package/foundation-v2-peercoin)
[![Known Vulnerabilities](https://snyk.io/test/npm/foundation-v2-peercoin/badge.svg)](https://snyk.io/test/npm/foundation-v2-peercoin)
[![Discord](https://img.shields.io/discord/738590795384356904)](https://discord.gg/rNjez6VgNF)

This portal is a high performance stratum server written entirely in Node.js. One instance of this software can startup and manage multiple coin pools, each with their own daemon and stratum ports. This server itself was built to be efficient, transparent, and easy to setup, while still maintaining greater scalability than many of the other open-source stratum servers. While this module will allow you to connect and mine directly on the a coin's blockchain, it doesn't include support for an API, payment processor, or share handler. For a complete server that includes these features and allows you to integrate multiple of these modules, see [here](https://github.com/blinkhash/foundation-v2-server).

#### Need Support?

If you need help with a code-related matter, the first place to look is our [Discord](https://discord.gg/rNjez6VgNF), where the developers will be available to answer any questions. However, please do not come to me with issues regarding setup. Use Google and the existing documentation for that.

---

### Donations

Maintaining this project has always been driven out of nothing more than a desire to give back to the mining community, however I always appreciate donations, especially if this repository helps you in any way.

- Bitcoin: 3EbrVYLxN5WeQmPpL6owo3A7rJELXecbbc
- Ethereum: 0xd3e3daED621d228244Fa89A3dd8AF07B52E72319
- Litecoin: MFWpARrSADAy3Qj79C4pSasS9F156QipwC
- ZCash: t1NSk8gyiou8TxWRZTVuUkfM5f9riopN58A

---

### License

Released under the GNU General Public License v3. See https://www.gnu.org/licenses/gpl-3.0 for more information

---

==> foundation-v2-peercoin-0.0.13.tgz: package/README.md <==
# Foundation Stratum (Peercoin, v2)

[![Codecov Coverage](https://img.shields.io/codecov/c/github/blinkhash/foundation-v2-peercoin.svg?style=flat-square)](https://codecov.io/gh/blinkhash/foundation-v2-peercoin/)
[![Foundation CI](https://github.com/blinkhash/foundation-v2-peercoin/actions/workflows/build.yml/badge.svg?branch=master)](https://github.com/blinkhash/foundation-v2-peercoin/actions/workflows/build.yml)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Downloads](https://img.shields.io/npm/dm/foundation-v2-peercoin.svg)](https://www.npmjs.com/package/foundation-v2-peercoin)
[![Version](https://img.shields.io/npm/v/foundation-v2-peercoin.svg)](https://www.npmjs.com/package/foundation-v2-peercoin)
[![Known Vulnerabilities](https://snyk.io/test/npm/foundation-v2-peercoin/badge.svg)](https://snyk.io/test/npm/foundation-v2-peercoin)
[![Discord](https://img.shields.io/discord/738590795384356904)](https://discord.gg/rNjez6VgNF)

This portal is a high performance stratum server written entirely in Node.js. This server itself was built to be efficient, transparent, and easy to setup, while still maintaining greater scalability than many of the other open-source stratum servers. While this module will allow you to connect and mine directly on the a coin's blockchain, it doesn't include support for an API, payment processor, or share handler. For a complete server that includes these features and allows you to integrate multiple of these modules, see [here](https://github.com/blinkhash/foundation-v2-server).

#### Need Support?

If you need help with a code-related matter, the first place to look is our [Discord](https://discord.gg/rNjez6VgNF), where the developers will be available to answer any questions. However, please do not come to me with issues regarding setup. Use Google and the existing documentation for that.

---

### Donations

Maintaining this project has always been driven out of nothing more than a desire to give back to the mining community, however I always appreciate donations, especially if this repository helps you in any way.

- Bitcoin: 3EbrVYLxN5WeQmPpL6owo3A7rJELXecbbc
- Ethereum: 0xd3e3daED621d228244Fa89A3dd8AF07B52E72319
- Litecoin: MFWpARrSADAy3Qj79C4pSasS9F156QipwC
- ZCash: t1NSk8gyiou8TxWRZTVuUkfM5f9riopN58A

---

### License

Released under the GNU General Public License v3. See https://www.gnu.org/licenses/gpl-3.0 for more information

---
